@@ -2,9 +2,16 @@
 # coding=utf-8
 
 
+def isstr(s):
+    try:
+        return isinstance(s, basestring)
+    except NameError:
+        return isinstance(s, str)
+
+
 def cf_safe_name(name):
     import re
-    if isinstance(name, str):
+    if isstr(name):
         if re.match('^[0-9_]', name):
             # Add a letter to the front
             name = "v_{}".format(name)
